@@ -242,7 +242,7 @@ class ClClientSyncLoginAction(Action):
          },
         # отключить удалённый профиль
         {'name': 'domain_sync:umount_unix',
-         'method': 'Client.umountPath(cl_client_user_mount_unix_path)',
+         'method': 'Client.umountRemoteUser(True,"unix","remote_profile")',
          'depend': Tasks.hasnot('failed')
          },
         # отключить ресурсы в случае ошибки
